# Python version
Please write here the output of printing ``sys.version``

# Platform information
Please write here the output of printing ``platform.platform()``

# Numpy version
Please write here the output of printing ``numpy.__version__``

# mdfreader version
Please write here the output of printing ``mdfreader.__version__``

# Description
Please describe the issue pr error stack here and eventually script used to use mdfreader

Also mentioning version of mdf file will be helpful (using mdfvalidator or mdfreader if functional for reading)

print of issue related variables at the errors location and eventually mdfvalidator screenshots can help troubleshooting complicated issues
